// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

package com.volcengine.reactnative.vertc.vod;

import android.graphics.SurfaceTexture;
import android.opengl.EGL14;
import android.opengl.EGLConfig;
import android.opengl.EGLContext;
import android.opengl.EGLDisplay;
import android.opengl.EGLSurface;
import android.opengl.GLES11Ext;
import android.opengl.GLES20;
import android.os.Handler;
import android.os.HandlerThread;
import android.util.Log;

import androidx.annotation.NonNull;

import javax.microedition.khronos.opengles.GL10;

public class OESTextureProcessor {
  public interface IProcessorCallback {
    void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height);

    void onSurfaceTextureDestroyed(SurfaceTexture surface);

    void onFrameAvailable(EGLContext eglContext, int oesTextureId, float[] transformMatrix, int width, int height, long timestamp);
  }

  public class EmptyProcessorCallback implements OESTextureProcessor.IProcessorCallback {
    @Override
    public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {

    }

    @Override
    public void onSurfaceTextureDestroyed(SurfaceTexture surface) {

    }

    @Override
    public void onFrameAvailable(EGLContext eglContext, int oesTextureId, float[] transformMatrix, int width, int height, long timestamp) {

    }
  }

  static final String TAG = "OESTextureProcessor";

  private static final Handler sHandler;

  static {
    HandlerThread thread = new HandlerThread("OESTextProcessor", Thread.MAX_PRIORITY);
    thread.start();
    sHandler = new Handler(thread.getLooper());
  }

  private int mOESTextureId;
  private EGLDisplay mEGLDisplay = EGL14.EGL_NO_DISPLAY;
  private EGLSurface mEGLSurface = EGL14.EGL_NO_SURFACE;
  private EGLContext mEGLContext = EGL14.EGL_NO_CONTEXT;
  private SurfaceTexture mSurfaceTexture;

  @NonNull
  private IProcessorCallback mProcessorCallback = new EmptyProcessorCallback();

  private final float[] mTransformMatrix = new float[16];
  private boolean mDestroyed = false;

  public OESTextureProcessor() {}

  private int genOESTexture() {
    int[] textureIds = new int[1];
    GLES20.glGenTextures(1, textureIds, 0);
    GLES20.glBindTexture(GLES11Ext.GL_TEXTURE_EXTERNAL_OES, textureIds[0]);
    GLES20.glTexParameterf(GLES11Ext.GL_TEXTURE_EXTERNAL_OES, GL10.GL_TEXTURE_MIN_FILTER, GL10.GL_NEAREST);
    GLES20.glTexParameterf(GLES11Ext.GL_TEXTURE_EXTERNAL_OES, GL10.GL_TEXTURE_MAG_FILTER, GL10.GL_LINEAR);
    GLES20.glTexParameterf(GLES11Ext.GL_TEXTURE_EXTERNAL_OES, GL10.GL_TEXTURE_WRAP_S, GL10.GL_CLAMP_TO_EDGE);
    GLES20.glTexParameterf(GLES11Ext.GL_TEXTURE_EXTERNAL_OES, GL10.GL_TEXTURE_WRAP_T, GL10.GL_CLAMP_TO_EDGE);
    GLES20.glBindTexture(GLES11Ext.GL_TEXTURE_EXTERNAL_OES, 0);
    return textureIds[0];
  }

  public void initSurfaceTexture(int width, int height, @NonNull IProcessorCallback callback) {
    mProcessorCallback = callback;
    sHandler.post(() -> {
      if (mSurfaceTexture == null) {
        eglSetup(width, height);
        mOESTextureId = genOESTexture();
        mSurfaceTexture = new SurfaceTexture(mOESTextureId);
        mSurfaceTexture.setOnFrameAvailableListener(surfaceTexture -> {
          surfaceTexture.getTransformMatrix(mTransformMatrix);
          callback.onFrameAvailable(mEGLContext, mOESTextureId, mTransformMatrix, width, height, surfaceTexture.getTimestamp());
          if (!mDestroyed) {
            surfaceTexture.updateTexImage();
          }
        });

        callback.onSurfaceTextureAvailable(mSurfaceTexture, width, height);
      }
    });
  }

  private void releaseSurfaceTextureImpl() {
    mProcessorCallback.onSurfaceTextureDestroyed(mSurfaceTexture);
    SurfaceTexture surfaceTexture = mSurfaceTexture;
    if (surfaceTexture != null) {
      if (mEGLDisplay != EGL14.EGL_NO_DISPLAY) {
        EGL14.eglDestroySurface(mEGLDisplay, mEGLSurface);
        EGL14.eglDestroyContext(mEGLDisplay, mEGLContext);
        EGL14.eglReleaseThread();
        EGL14.eglTerminate(mEGLDisplay);
      }
      mEGLDisplay = EGL14.EGL_NO_DISPLAY;
      mEGLContext = EGL14.EGL_NO_CONTEXT;
      mEGLSurface = EGL14.EGL_NO_SURFACE;
      surfaceTexture.setOnFrameAvailableListener(null);
      surfaceTexture.release();
    }
    mSurfaceTexture = null;
  }

  public void destroy() {
    mDestroyed = true;
    releaseSurfaceTextureImpl();
    sHandler.removeCallbacksAndMessages(null);
  }

  private void eglSetup(int width, int height) {
    mEGLDisplay = EGL14.eglGetDisplay(EGL14.EGL_DEFAULT_DISPLAY);
    if (mEGLDisplay == EGL14.EGL_NO_DISPLAY) {
      Log.w(TAG, "unable to get EGL14 display");
    }
    int[] version = new int[2];
    if (!EGL14.eglInitialize(mEGLDisplay, version, 0, version, 1)) {
      mEGLDisplay = null;
      Log.w(TAG, "unable to initialize EGL14");
    }
    // Configure EGL for pbuffer and OpenGL ES 2.0, 32-bit RGB.
    int[] attribList = {
      EGL14.EGL_BUFFER_SIZE, 32,
      EGL14.EGL_RED_SIZE, 8,
      EGL14.EGL_GREEN_SIZE, 8,
      EGL14.EGL_BLUE_SIZE, 8,
      EGL14.EGL_ALPHA_SIZE, 8,
      EGL14.EGL_RENDERABLE_TYPE, EGL14.EGL_OPENGL_ES2_BIT,
      EGL14.EGL_SURFACE_TYPE, EGL14.EGL_PBUFFER_BIT,
      EGL14.EGL_NONE
    };
    EGLConfig[] configs = new EGLConfig[1];
    int[] numConfigs = new int[1];
    if (!EGL14.eglChooseConfig(mEGLDisplay, attribList, 0, configs, 0, configs.length,
      numConfigs, 0)) {
      Log.w(TAG, "unable to find RGB888+recordable ES2 EGL config");
    }

    // Configure context for OpenGL ES 2.0.
    int[] attrib_list = {
      EGL14.EGL_CONTEXT_CLIENT_VERSION, 2,
      EGL14.EGL_NONE
    };
    mEGLContext = EGL14.eglCreateContext(mEGLDisplay, configs[0], EGL14.EGL_NO_CONTEXT,
      attrib_list, 0);
    if (mEGLContext == null) {
      Log.w(TAG, "null context");
    }
    // Create a pbuffer surface.
    int[] surfaceAttribs = {
      EGL14.EGL_WIDTH, width,
      EGL14.EGL_HEIGHT, height,
      EGL14.EGL_NONE
    };
    mEGLSurface = EGL14.eglCreatePbufferSurface(mEGLDisplay, configs[0], surfaceAttribs, 0);
    if (mEGLSurface == null) {
      Log.w(TAG, "surface was null");
    }

    if (!EGL14.eglMakeCurrent(mEGLDisplay, mEGLSurface, mEGLSurface, mEGLContext)) {
      Log.w(TAG, "eglMakeCurrent failed");
    }
  }
}
