// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

package com.volcengine.reactnative.vertc.vod;

import android.util.Log;

import androidx.annotation.NonNull;

import com.ss.bytertc.engine.RTCVideo;
import com.ss.bytertc.engine.audio.IAudioMixingManager;
import com.ss.bytertc.engine.data.AudioChannel;
import com.ss.bytertc.engine.data.AudioMixingType;
import com.ss.bytertc.engine.data.AudioSampleRate;
import com.ss.bytertc.engine.data.AudioSourceType;
import com.ss.bytertc.engine.utils.AudioFrame;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

public class VodAudioProcessor {
    public String TAG = "VodAudioProcessor";
    public static final int VIDEO_AUDIO_GAIN = 20;
    public static volatile int mixAudioGain = VIDEO_AUDIO_GAIN; // 0~100
    private int mChannelCount;
    private int mSampleRate;

    @NonNull
    private final RTCVideo mRTCEngine;
    @NonNull
    private final IAudioMixingManager mixAudioManager;

    private ByteBuffer mRTCBuffer;

    private static final int MIX_ID = 199;

    public VodAudioProcessor(@NonNull RTCVideo engine) {
        mRTCEngine = engine;
        mixAudioManager = mRTCEngine.getAudioMixingManager();
        mixAudioManager.enableAudioMixingFrame(MIX_ID, AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT);
        engine.setScreenAudioSourceType(AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL);
    }

    public void audioOpen(int sampleRate, int channelCount) {
        this.mChannelCount = channelCount;
        this.mSampleRate = sampleRate;
    }

    public void audioProcess(ByteBuffer[] byteBuffers, int samples, long timestamp) {
//        Log.d(TAG, "audioProcess start, buffer size:" + byteBuffers.length);

        int channelsCount = mChannelCount;
        int length = samples * channelsCount * 2;
        if (mRTCBuffer == null || mRTCBuffer.capacity() < length) {
            mRTCBuffer = ByteBuffer.allocate(length);
            mRTCBuffer.order(ByteOrder.LITTLE_ENDIAN);
        }
        mRTCBuffer.clear();
        ByteBuffer srcBuffer0 = byteBuffers[0];
        srcBuffer0.order(ByteOrder.LITTLE_ENDIAN);
        ByteBuffer srcBuffer1 = null;
        if (channelsCount > 1) {
            srcBuffer1 = byteBuffers[1];
            srcBuffer1.order(ByteOrder.LITTLE_ENDIAN);
        }
        for (int i = 0; i < samples; i++) {
            oneSampleFLTPtoS16(srcBuffer0, mRTCBuffer);
            if (srcBuffer1 != null) {
                oneSampleFLTPtoS16(srcBuffer1, mRTCBuffer);
            }
        }

        AudioChannel channel = getAudioChannel(mChannelCount);
        AudioSampleRate sampleRate = getAudioSampleRate(mSampleRate);
        AudioFrame frame = new AudioFrame(mRTCBuffer.array(), samples, sampleRate, channel);
        this.writeFrame(frame);
    }
    
    public void writeFrame(AudioFrame frame) {
      mixAudioManager.setAudioMixingVolume(MIX_ID, mixAudioGain, AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT);

      int push_mix_status = mixAudioManager.pushAudioMixingFrame(MIX_ID, frame);
      if (push_mix_status != 0) {
        Log.d(TAG, "pushExternalAudioFrame: " + push_mix_status);
      }

      int ret_status = mRTCEngine.pushScreenAudioFrame(frame);
      boolean success = ret_status == 0;
      if (!success) {
        Log.d(TAG, "pushScreenAudioFrame fail: " + ret_status);
      }
    }

    /* {zh}
     * @brief 将一个采样的数据格式从 FLTP 转换为 S16
     */
    private void oneSampleFLTPtoS16(ByteBuffer srcBuffer, ByteBuffer dstBuffer) {
        float sample = srcBuffer.getFloat();
        int value = (int) (1.0f * sample * Short.MAX_VALUE);
        if (value > Short.MAX_VALUE) {
            value = Short.MAX_VALUE;
        } else if (value < Short.MIN_VALUE) {
            value = Short.MIN_VALUE;
        }
        dstBuffer.putShort((short) (value));
    }

    private AudioSampleRate getAudioSampleRate(int sampleRate) {
        if (sampleRate == 8000) {
            return AudioSampleRate.AUDIO_SAMPLE_RATE_8000;
        } else if (sampleRate == 16000) {
            return AudioSampleRate.AUDIO_SAMPLE_RATE_16000;
        } else if (sampleRate == 32000) {
            return AudioSampleRate.AUDIO_SAMPLE_RATE_32000;
        } else if (sampleRate == 44100) {
            return AudioSampleRate.AUDIO_SAMPLE_RATE_44100;
        } else if (sampleRate == 48000) {
            return AudioSampleRate.AUDIO_SAMPLE_RATE_48000;
        }
        return AudioSampleRate.AUDIO_SAMPLE_RATE_AUTO;
    }

    private AudioChannel getAudioChannel(int channelCount) {
        if (channelCount == 1) {
            return AudioChannel.AUDIO_CHANNEL_MONO;
        } else if (channelCount == 2) {
            return AudioChannel.AUDIO_CHANNEL_STEREO;
        }
        return AudioChannel.AUDIO_CHANNEL_AUTO;
    }
}
