// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

import { ICreateRTCEngineOptions, IEngine, ILogConfigs, IRoom, I_AudioEffectPlayer, I_MediaPlayer } from './interface';
/** {en}
 * @detail api
 * @brief RTC core class, responsible for managing the created engine instance and room instance
 */
export declare class RTCManager {
    /** {en}
     * @brief RTC Engine instance
     */
    engine?: IEngine;
    /** {en}
     * @brief RTC room instance
     */
    room?: IRoom;
    /** {en}
     * @brief RTC AudioEffectPlayer instance
     */
    audioEffectPlayer?: I_AudioEffectPlayer;
    /** {en}
     * @brief RTC MediaPlayer instance
     */
    mediaPlayer?: I_MediaPlayer;
    /** {en}
     * @brief Vod Player instance
     */
    vodPlayer?: unknown;
    /** {en}
     * @brief Get React Native SDK Version
     */
    getSDKVersion: () => string | undefined;
    /** {en}
     * @brief Get Basic Android/iOS SDK Version
     */
    getBasicSDKVersion: () => string;
    /** {en}
     * @brief Creates an engine instance.
     *        This is the very first API that you must call if you want to use all the RTC capabilities.
     *        If there is no engine instance in current process, calling this API will create one. If an engine instance has been created, calling this API again will have the created engine instance returned.
     * @param options Engine initialize params. See {@link ICreateRTCEngineOptions ICreateRTCEngineOptions}.
     * @return
     *         - engine: A successfully created engine instance.
     *         - null: ICreateRTCEngineOptions is inValid. See {@link ICreateRTCEngineOptions ICreateRTCEngineOptions}. Failed to load the so file.
     * @note The lifecycle of the handler must be longer than that of the RTCVideo, i.e. the handler must be destroyed after calling {@link destroyRTCEngine destroyRTCEngine}.
     */
    createRTCEngine: (options: ICreateRTCEngineOptions) => Promise<IEngine>;
    /** {en}
     * @brief Destroy the engine instance created by {@link createRTCEngine createRTCEngine}, and release all related resources.
     * @note
     *       - Call this API after all business scenarios related to the engine instance are destroyed.
     *       - When the API is called, RTC SDK destroys all memory associated with the engine instance and stops any interaction with the media server.
     *       - Calling this API will start the SDK exit logic. The engine thread is held until the exit logic is complete. The engine thread is retained until the exit logic is complete. Therefore, do not call this API directly in the callback thread, or it will cause a deadlock. This function takes a long time to execute, so it's not recommended to call this API in the main thread, or the main thread may be blocked.
     */
    destroyRTCEngine: () => void;
    /** {en}
     * @region Engine Management
     * @brief Configures the local log parameters of RTC SDK, including the logging level, directory, the limits for total log file size, and the prefix to the log file.
     * @param config Local log parameters.
     * @return
     *        - 0: Success.
     *        - –1: Failure. This API must be called before creating engine.
     *        - –2: Failure. Invalid parameters.
     * @note This API must be called before engine created.
     * @list Engine Management
     */
    setLogConfig(config: ILogConfigs): number;
    /** {en}
     * @brief Set vod-player instance
     */
    setVodPlayer(vodPlayer: unknown): void;
}
